#!/bin/sh

video=`zenity --entry --title='Download Video' --text='Inserisci il nome del video' --entry-text='Puntata7'`
	if [ $? -eq 0 ]
		then
			ricrem=`zenity --question --title Download --text "Sei sicuro di voler scaricare il video? 
Se sei sicuro premi OK, altrimenti CANCEL";echo $?`
				if [ "$ricrem" -eq "0" ]
					then
						mkdir /home/user/MyDocs/Puntate\ Servizio\ Pubblico/ 1>/dev/null 2>/dev/null
						osso-xterm -e "youtube-dl http://www.youtube.com/watch?v=bnKDv2ELw0Y -o /home/user/MyDocs/Puntate\ Servizio\ Pubblico/$video.mp4"
					else
						dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Annullato!"
				fi
		else
			dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Annullato!"
	fi
